# Registry Maintainer Onboarding

This guide covers onboarding new maintainers to the MCP Registry project.

## Checklist

When onboarding a new maintainer, complete the following steps:

### 1. Access Repository (GitHub, Google Workspace)

- [ ] Open a PR on the [modelcontextprotocol/access](https://github.com/modelcontextprotocol/access) repository

### 2. MAINTAINERS.md

- [ ] Add them to the `MAINTAINERS.md` file in [modelcontextprotocol/modelcontextprotocol](https://github.com/modelcontextprotocol/modelcontextprotocol)

### 3. README.md

- [ ] Add them to the "Current key maintainers" section in [README.md](../../README.md)

### 4. Discord

- [ ] Invite them to the MCP Discord server
- [ ] Ask a Community Moderator or Core Maintainer to add them to the appropriate roles
